@@ -254,12 +254,14 @@ const string kModelFileString = "model_file";
 const string kPresolveString = "presolve";
 const string kSolverString = "solver";
 const string kParallelString = "parallel";
+const string kRunCrossoverString = "run_crossover";
 const string kTimeLimitString = "time_limit";
 const string kOptionsFileString = "options_file";
 const string kRandomSeedString = "random_seed";
 const string kSolutionFileString = "solution_file";
 const string kRangingString = "ranging";
 const string kWriteModelFileString = "write_model_file";
+const string kReadSolutionFileString = "read_solution_file";
 
 // String for HiGHS log file option
 const string kLogFileString = "log_file";
@@ -269,8 +271,12 @@ struct HighsOptionsStruct {
   std::string presolve;
   std::string solver;
   std::string parallel;
-  std::string ranging;
+  std::string run_crossover;
   double time_limit;
+  std::string solution_file;
+  std::string write_model_file;
+  HighsInt random_seed;
+  std::string ranging;
 
   // Options read from the file
   double infinite_cost;
@@ -282,7 +288,6 @@ struct HighsOptionsStruct {
   double ipm_optimality_tolerance;
   double objective_bound;
   double objective_target;
-  HighsInt random_seed;
   HighsInt threads;
   HighsInt highs_debug_level;
   HighsInt highs_analysis_level;
@@ -295,21 +300,23 @@ struct HighsOptionsStruct {
   HighsInt simplex_update_limit;
   HighsInt simplex_min_concurrency;
   HighsInt simplex_max_concurrency;
-  HighsInt ipm_iteration_limit;
-  std::string write_model_file;
-  std::string solution_file;
+
   std::string log_file;
   bool write_model_to_file;
   bool write_solution_to_file;
   HighsInt write_solution_style;
   HighsInt glpsol_cost_row_location;
+
   // Control of HiGHS log
   bool output_flag;
   bool log_to_console;
 
+  // Options for IPM solver
+  HighsInt ipm_iteration_limit;
+
   // Advanced options
   HighsInt log_dev_level;
-  bool run_crossover;
+  bool solve_relaxation;
   bool allow_unbounded_or_infeasible;
   bool use_implied_bounds_from_presolve;
   bool lp_presolve_requires_basis_postsolve;
@@ -443,7 +450,10 @@ class HighsOptions : public HighsOptionsStruct {
     records.push_back(record_string);
 
     record_string = new OptionRecordString(
-        kSolverString, "Solver option: \"simplex\", \"choose\" or \"ipm\"",
+        kSolverString,
+        "Solver option: \"simplex\", \"choose\" or \"ipm\". If "
+        "\"simplex\"/\"ipm\" is chosen then, for a MIP (QP) the integrality "
+        "constraint (quadratic term) will be ignored",
         advanced, &solver, kHighsChooseString);
     records.push_back(record_string);
 
@@ -452,6 +462,11 @@ class HighsOptions : public HighsOptionsStruct {
         advanced, &parallel, kHighsChooseString);
     records.push_back(record_string);
 
+    record_string = new OptionRecordString(
+        kRunCrossoverString, "Run IPM crossover: \"off\", \"choose\" or \"on\"",
+        advanced, &run_crossover, kHighsOnString);
+    records.push_back(record_string);
+
     record_double =
         new OptionRecordDouble(kTimeLimitString, "Time limit (seconds)",
                                advanced, &time_limit, 0, kHighsInf, kHighsInf);
@@ -594,11 +609,6 @@ class HighsOptions : public HighsOptionsStruct {
         &simplex_update_limit, 0, 5000, kHighsIInf);
     records.push_back(record_int);
 
-    record_int = new OptionRecordInt(
-        "ipm_iteration_limit", "Iteration limit for IPM solver", advanced,
-        &ipm_iteration_limit, 0, kHighsIInf, kHighsIInf);
-    records.push_back(record_int);
-
     record_int = new OptionRecordInt(
         "simplex_min_concurrency",
         "Minimum level of concurrency in parallel simplex", advanced,
@@ -804,6 +814,11 @@ class HighsOptions : public HighsOptionsStruct {
         advanced, &mip_abs_gap, 0.0, 1e-6, kHighsInf);
     records.push_back(record_double);
 
+    record_int = new OptionRecordInt(
+        "ipm_iteration_limit", "Iteration limit for IPM solver", advanced,
+        &ipm_iteration_limit, 0, kHighsIInf, kHighsIInf);
+    records.push_back(record_int);
+
     // Advanced options
     advanced = true;
 
@@ -814,9 +829,9 @@ class HighsOptions : public HighsOptionsStruct {
         kHighsLogDevLevelMax);
     records.push_back(record_int);
 
-    record_bool = new OptionRecordBool("run_crossover",
-                                       "Run the crossover routine for IPX",
-                                       advanced, &run_crossover, true);
+    record_bool = new OptionRecordBool(
+        "solve_relaxation", "Solve the relaxation of discrete model components",
+        advanced, &solve_relaxation, false);
     records.push_back(record_bool);
 
     record_bool =
